/*
' Copyright (c) 2012 Konk Corporation
'  All rights reserved.
' 
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
' DEALINGS IN THE SOFTWARE.
' 
*/

using System;
using DotNetNuke.Services.Exceptions;
using DotNetNuke.Entities.Users;
using Konk.Modules.TaskManager.Components;

namespace Konk.Modules.TaskManager
{

    /// -----------------------------------------------------------------------------
    /// <summary>
    /// The EditTaskManager class is used to manage content
    /// 
    /// Typically your edit control would be used to create new content, or edit existing content within your module.
    /// The ControlKey for this control is "Edit", and is defined in the manifest (.dnn) file.
    /// 
    /// Because the control inherits from TaskManagerModuleBase you have access to any custom properties
    /// defined there, as well as properties from DNN such as PortalId, ModuleId, TabId, UserId and many more.
    /// 
    /// </summary>
    /// -----------------------------------------------------------------------------
    public partial class Edit : TaskManagerModuleBase
    {

        #region Event Handlers

        override protected void OnInit(EventArgs e)
        {
            InitializeComponent();
            base.OnInit(e);
        }

        private void InitializeComponent()
        {
            this.Load += new System.EventHandler(this.Page_Load);
        }

        /// -----------------------------------------------------------------------------
        /// <summary>
        /// Page_Load runs when the control is loaded
        /// </summary>
        /// -----------------------------------------------------------------------------
        private void Page_Load(object sender, System.EventArgs e)
        {
            try
            {
                //Implement your edit logic for your module

                if (!Page.IsPostBack)
                {


                    //UserController.GetUsers - uso da API DotNetNuke
                    //PortalID  acessivel a partir de TaskManagerModuleBase

                    ddlAssignedUser.DataSource = UserController.GetUsers(PortalId); //uso normal

                    //ddlAssignedUser.DataSource = UserController.GetUsers(0); //uso de teste
                    ddlAssignedUser.DataTextField = "Username";
                    ddlAssignedUser.DataValueField = "UserId";
                    ddlAssignedUser.DataBind();

                    if (TaskId > 0)
                    {
                        var task = TaskController.GetTask(TaskId);

                        if (task != null)
                        {
                            txtName.Text = task.TaskName;
                            txtdescription.Text = task.TaskDescription;
                            txtTargetCompletionDate.Text = task.TargetCompletionDate.ToString();
                            txtCompletionDate.Text = task.CompletedOnDate.ToString();
                            ddlAssignedUser.Items.FindByValue(task.AssignedUserId.ToString()).Selected = true;
                        }

                    }

                }

            }
            catch (Exception exc) //Module failed to load
            {
                Exceptions.ProcessModuleLoadException(this, exc);
            }
        }

        #endregion

        protected void btnSubmit_Click(object sender, EventArgs e)
        {
            //criar e guardar uma task
            Task t;

            if (TaskId > 0)
            {
                t = TaskController.GetTask(ModuleId);

                t.TaskName = txtName.Text.Trim();
                t.TaskDescription = txtdescription.Text.Trim();
                t.LastModifiedByUserId = UserId;
                t.LastModifiedOnDate = DateTime.Now;
                t.AssignedUserId = Convert.ToInt32(ddlAssignedUser.SelectedValue);
            }
            else
            {
                Task t2 = new Task();

                t2.AssignedUserId = Convert.ToInt32(ddlAssignedUser.SelectedValue);
                //t.CompletedOnDate = Convert.ToDateTime( txtCompletionDate.Text.Trim()); //Erro na execuo pois se o valor for Null no  possivel converter
                t2.CreatedByUserId = UserId;//user que est logado - acessivel atraves de TaskManagerModuleBase
                t2.CreatedOnDate = DateTime.Now;
                //t.TargetCompletionDate = Convert.ToDateTime( txtTargetCompletionDate.Text.Trim()); //Erro na execuo pois se o valor for Null no  possivel converter
                t2.TaskName = txtName.Text.Trim();
                t2.TaskDescription = txtdescription.Text.Trim();
                t2.ModuleId = ModuleId;//ModuleId acedido no ModuleBase
            }




            //verificar as datas
            DateTime outputDate;
            DateTime outputDate2;

            if (DateTime.TryParse(txtCompletionDate.Text.Trim(), out outputDate))
            {
                t.CompletedOnDate = outputDate;
            }

            if (DateTime.TryParse(txtTargetCompletionDate.Text.Trim(), out outputDate2))
            {
                t.TargetCompletionDate = outputDate2;
            }


            //Guardar a task
            TaskController.SaveTask(t, TabId);
            Response.Redirect(DotNetNuke.Common.Globals.NavigateURL());


        }

        protected void btncancel_Click(object sender, EventArgs e)
        {
            //se cancelar navega para a pagina em que estava.
            Response.Redirect(DotNetNuke.Common.Globals.NavigateURL());
        }

    }

}