/*
' Copyright (c) 2012  Konk Corporation
'  All rights reserved.
' 
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
' DEALINGS IN THE SOFTWARE.
' 
*/

using System;
using DotNetNuke.Services.Exceptions;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Entities.Modules.Actions;
using DotNetNuke.Services.Localization;
using DotNetNuke.Security;
using Konk.Modules.TaskManager.Components;
using System.Web.UI.WebControls;
using DotNetNuke.UI.Utilities;

namespace Konk.Modules.TaskManager
{

    /// -----------------------------------------------------------------------------
    /// <summary>
    /// The View class displays the content
    /// 
    /// Typically your view control would be used to display content or functionality in your module.
    /// 
    /// View may be the only control you have in your project depending on the complexity of your module
    /// 
    /// Because the control inherits from TaskManagerModuleBase you have access to any custom properties
    /// defined there, as well as properties from DNN such as PortalId, ModuleId, TabId, UserId and many more.
    /// 
    /// </summary>
    /// -----------------------------------------------------------------------------
    public partial class View : TaskManagerModuleBase, IActionable
    {

        #region Event Handlers

        override protected void OnInit(EventArgs e)
        {
            InitializeComponent();
            base.OnInit(e);
        }

        private void InitializeComponent()
        {
            this.Load += new System.EventHandler(this.Page_Load);
        }


        /// -----------------------------------------------------------------------------
        /// <summary>
        /// Page_Load runs when the control is loaded
        /// </summary>
        /// -----------------------------------------------------------------------------
        private void Page_Load(object sender, System.EventArgs e)
        {
            try
            {
                rptTaskList.DataSource = TaskController.GetTasks(ModuleId);//acesso via PortalModuleBase
                rptTaskList.DataBind();
            }
            catch (Exception exc) //Module failed to load
            {
                Exceptions.ProcessModuleLoadException(this, exc);
            }
        }


        //para o evento definido na view.ascx no datarepeater
        protected void rptTaskListOnItemDataBound(object sender, RepeaterItemEventArgs e)
        {
            //verificar se o tipo  "AlternatingItem" ou do tipo "Item" "pnlAdmin"
            if (e.Item.ItemType == ListItemType.AlternatingItem || e.Item.ItemType == ListItemType.Item)
            {
                //procurar os controlos "lnkEdit", "lnkDelete", "pnlAdmin"
                var lnkEdit = e.Item.FindControl("lnkEdit") as LinkButton;
                var lnkDelete = e.Item.FindControl("lnkDelete") as LinkButton;

                var pnlAdminControls = e.Item.FindControl("pnlAdmin") as Panel;

               //instanciar a task actual
                var curTask = (Task)e.Item.DataItem;


                //verificar se o utilizador pose editar a task "IsEditable"
                //garantir que encontramos os controlos e por isso no so nulos
                if (IsEditable && lnkDelete != null && lnkEdit != null && pnlAdminControls != null)
                 {
                    pnlAdminControls.Visible = true;
                    lnkEdit.CommandArgument = curTask.TaskId.ToString();

                    //lnkEdit.Enabled = lnkEdit.Visible = true;

                    lnkDelete.CommandArgument = lnkEdit.CommandArgument = curTask.TaskId.ToString();
                    lnkDelete.Enabled = lnkDelete.Visible = lnkEdit.Enabled = lnkEdit.Visible = true;

                    //Usando a API do DotNetNuke para apresentar uma menssagem de confirmao
                    ClientAPI.AddButtonConfirm(lnkDelete, Localization.GetString("ConfirmDelete", LocalResourceFile));


                }
                else
                {
                    pnlAdminControls.Visible = false;
                }
            }

        }

        // executado quando alguem clica no link
        public void rptTaskListOnItemCommand(object source, RepeaterCommandEventArgs e)
        {
            //verificar se o controlo foi "Edit"
            if (e.CommandName == "Edit")
            {
                 //Response.Redirect(EditUrl(string.Empty, string.Empty, "Edit", "tid=" + e.CommandArgument));

                Response.Redirect(DotNetNuke.Common.Globals.NavigateURL(PortalSettings.ActiveTab.TabID, "Edit", "mid=" + ModuleId.ToString(), "tid=" + e.CommandArgument));

            }
            //verificar se o controlo foi "Delete"
            if (e.CommandName == "Delete")
            {
                //metodo da class TaskController com o argumento (e.CommandArgument) que  o id da task
                TaskController.DeleteTask(Convert.ToInt32(e.CommandArgument));
            }

            Response.Redirect(DotNetNuke.Common.Globals.NavigateURL());
        }


        #endregion

        #region Optional Interfaces

        public ModuleActionCollection ModuleActions
        {
            get
            {
                ModuleActionCollection Actions = new ModuleActionCollection();
                Actions.Add(GetNextActionID(), Localization.GetString("EditModule", this.LocalResourceFile), "", "", "", EditUrl(), false, SecurityAccessLevel.Edit, true, false);
                return Actions;
            }
        }

        #endregion

    }

}
